@@ -1,19 +1,34 @@
-from signal import signal, SIGINT
-import pyzed.sl as sl
-import threading
-import time
-import signal
 import logging
 import os
-from src.record import get_intrinsic_parameters
+import signal
+import threading
+import time
+
+import pyzed.sl as sl
+
+zed_list = []
 
 
-def signal_handler(signal, frame, zed_list):
+def get_intrinsic_parameters(cam):
+    calibration_params = cam.get_camera_information().camera_configuration.calibration_parameters
+    # Focal length of the left eye in pixels
+    focal_left_x = calibration_params.left_cam.fx
+    # First radial distortion coefficient
+    k1 = calibration_params.left_cam.disto[0]
+    # Translation between left and right eye on z-axis
+
+    t = calibration_params.T
+    # Horizontal field of view of the left eye in degrees
+    h_fov = calibration_params.left_cam.h_fov
+    return focal_left_x, k1, t, h_fov
+
+
+def signal_handler(signal, frame):
+    global zed_list
     print('ZED', zed_list)
     for cam in zed_list:
         cam.disable_recording()
         cam.close()
-    signal = True
     time.sleep(0.5)
     exit()
 
@@ -36,13 +51,15 @@ def grab_run(zed_list, recording_param_list, index):
 
 
 def record(root_dir, exp_name):
+    global zed_list
+
     if os.path.exists('{}/{}'.format(root_dir, exp_name)):
         raise Exception('There are already some files in {}, please rename the exp_name.'.format(
             '{}/{}'.format(root_dir, exp_name)))
     else:
         os.mkdir('{}/{}'.format(root_dir, exp_name))
+        print('Recording folder: {}/{}'.format(root_dir, exp_name))
 
-    zed_list = []
     left_list = []
     depth_list = []
     timestamp_list = []
@@ -63,7 +80,6 @@ def record(root_dir, exp_name):
     cameras = sl.Camera.get_device_list()
     index = 0
     for cam in cameras:
-
         init.set_from_serial_number(cam.serial_number)
         if index >= 2:
             init.sdk_gpu_id = 1
@@ -78,7 +94,7 @@ def record(root_dir, exp_name):
         timestamp_list.append(0)
         last_ts_list.append(0)
 
-        video_path = 'data/{}/{}.svo'.format(exp_name, cam.serial_number)
+        video_path = '{}/{}/{}.svo'.format(root_dir, exp_name, cam.serial_number)
         recording_param_list.append(sl.RecordingParameters(video_path, sl.SVO_COMPRESSION_MODE.H264))
         status = zed_list[index].open(init)
         if status != sl.ERROR_CODE.SUCCESS:
@@ -109,8 +125,12 @@ def record(root_dir, exp_name):
 
 
 if __name__ == "__main__":
-    root_dir = '/home/ubuntu/Data/zed_record'
-    exp_name = '20220909'
+    root_dir = '/home/skylark/Data/zed_record'
+    # exp_name = '20220916_1552'
+    # from time import gmtime, strftime
+    # exp_name = strftime("%Y%m%d_%H%M%S", gmtime())
+    from datetime import datetime
+    exp_name = datetime.now().strftime('%Y%m%d_%H%M%S')
 
     # record(root_dir, exp_name)
     import rofunc as rf
